@@ -1,41 +1,67 @@
 #include "debug_component.h"
+
+#include <algorithm>
 #include "esphome/core/log.h"
+#include "esphome/core/hal.h"
 #include "esphome/core/helpers.h"
-#include "esphome/core/defines.h"
 #include "esphome/core/version.h"
 
 #ifdef USE_ESP32
+
+#include <esp_heap_caps.h>
+#include <esp_system.h>
+
+#if ESP_IDF_VERSION_MAJOR >= 4
+#include <esp32/rom/rtc.h>
+#else
 #include <rom/rtc.h>
-#include <esp_idf_version.h>
 #endif
 
+#endif  // USE_ESP32
+
 #ifdef USE_ARDUINO
 #include <Esp.h>
 #endif
 
-#ifdef USE_ESP_IDF
-#include <esp_heap_caps.h>
-#include <esp_system.h>
-#endif
-
 namespace esphome {
 namespace debug {
 
 static const char *const TAG = "debug";
 
+static uint32_t get_free_heap() {
+#if defined(USE_ESP8266)
+  return ESP.getFreeHeap();  // NOLINT(readability-static-accessed-through-instance)
+#elif defined(USE_ESP32)
+  return heap_caps_get_free_size(MALLOC_CAP_INTERNAL);
+#endif
+}
+
 void DebugComponent::dump_config() {
+  std::string device_info;
+  device_info.reserve(256);
+
 #ifndef ESPHOME_LOG_HAS_DEBUG
   ESP_LOGE(TAG, "Debug Component requires debug log level!");
   this->status_set_error();
   return;
 #endif
 
+  ESP_LOGCONFIG(TAG, "Debug component:");
+#ifdef USE_TEXT_SENSOR
+  LOG_TEXT_SENSOR("  ", "Device info", this->device_info_);
+#endif  // USE_TEXT_SENSOR
+#ifdef USE_SENSOR
+  LOG_SENSOR("  ", "Free space on heap", this->free_sensor_);
+  LOG_SENSOR("  ", "Largest free heap block", this->block_sensor_);
+#if defined(USE_ESP8266) && USE_ARDUINO_VERSION_CODE >= VERSION_CODE(2, 5, 2)
+  LOG_SENSOR("  ", "Heap fragmentation", this->fragmentation_sensor_);
+#endif  // defined(USE_ESP8266) && USE_ARDUINO_VERSION_CODE >= VERSION_CODE(2, 5, 2)
+#endif  // USE_SENSOR
+
   ESP_LOGD(TAG, "ESPHome version %s", ESPHOME_VERSION);
-#ifdef USE_ARDUINO
-  this->free_heap_ = ESP.getFreeHeap();  // NOLINT(readability-static-accessed-through-instance)
-#elif defined(USE_ESP_IDF)
-  this->free_heap_ = heap_caps_get_free_size(MALLOC_CAP_INTERNAL);
-#endif
+  device_info += ESPHOME_VERSION;
+
+  this->free_heap_ = get_free_heap();
   ESP_LOGD(TAG, "Free Heap Size: %u bytes", this->free_heap_);
 
 #ifdef USE_ARDUINO
@@ -64,9 +90,12 @@ void DebugComponent::dump_config() {
     default:
       flash_mode = "UNKNOWN";
   }
-  // NOLINTNEXTLINE(readability-static-accessed-through-instance)
-  ESP_LOGD(TAG, "Flash Chip: Size=%ukB Speed=%uMHz Mode=%s", ESP.getFlashChipSize() / 1024,
-           ESP.getFlashChipSpeed() / 1000000, flash_mode);
+  ESP_LOGD(TAG, "Flash Chip: Size=%ukB Speed=%uMHz Mode=%s",
+           ESP.getFlashChipSize() / 1024,                                                   // NOLINT
+           ESP.getFlashChipSpeed() / 1000000, flash_mode);                                  // NOLINT
+  device_info += "|Flash: " + to_string(ESP.getFlashChipSize() / 1024) +                    // NOLINT
+                 "kB Speed:" + to_string(ESP.getFlashChipSpeed() / 1000000) + "MHz Mode:";  // NOLINT
+  device_info += flash_mode;
 #endif  // USE_ARDUINO
 
 #ifdef USE_ESP32
@@ -98,13 +127,24 @@ void DebugComponent::dump_config() {
     info.features &= ~CHIP_FEATURE_BT;
   }
   if (info.features)
-    features += "Other:" + uint64_to_string(info.features);
+    features += "Other:" + format_hex(info.features);
   ESP_LOGD(TAG, "Chip: Model=%s, Features=%s Cores=%u, Revision=%u", model, features.c_str(), info.cores,
            info.revision);
+  device_info += "|Chip: ";
+  device_info += model;
+  device_info += " Features:";
+  device_info += features;
+  device_info += " Cores:" + to_string(info.cores);
+  device_info += " Revision:" + to_string(info.revision);
 
   ESP_LOGD(TAG, "ESP-IDF Version: %s", esp_get_idf_version());
+  device_info += "|ESP-IDF: ";
+  device_info += esp_get_idf_version();
 
-  ESP_LOGD(TAG, "EFuse MAC: %s", get_mac_address_pretty().c_str());
+  std::string mac = get_mac_address_pretty();
+  ESP_LOGD(TAG, "EFuse MAC: %s", mac.c_str());
+  device_info += "|EFuse MAC: ";
+  device_info += mac;
 
   const char *reset_reason;
   switch (rtc_get_reset_reason(0)) {
@@ -157,6 +197,8 @@ void DebugComponent::dump_config() {
       reset_reason = "Unknown Reset Reason";
   }
   ESP_LOGD(TAG, "Reset Reason: %s", reset_reason);
+  device_info += "|Reset: ";
+  device_info += reset_reason;
 
   const char *wakeup_reason;
   switch (rtc_get_wakeup_cause()) {
@@ -200,6 +242,8 @@ void DebugComponent::dump_config() {
       wakeup_reason = "Unknown";
   }
   ESP_LOGD(TAG, "Wakeup Reason: %s", wakeup_reason);
+  device_info += "|Wakeup: ";
+  device_info += wakeup_reason;
 #endif
 
 #if defined(USE_ESP8266) && !defined(CLANG_TIDY)
@@ -211,20 +255,81 @@ void DebugComponent::dump_config() {
   ESP_LOGD(TAG, "Flash Chip ID=0x%08X", ESP.getFlashChipId());
   ESP_LOGD(TAG, "Reset Reason: %s", ESP.getResetReason().c_str());
   ESP_LOGD(TAG, "Reset Info: %s", ESP.getResetInfo().c_str());
+
+  device_info += "|Chip: 0x" + format_hex(ESP.getChipId());
+  device_info += "|SDK: ";
+  device_info += ESP.getSdkVersion();
+  device_info += "|Core: ";
+  device_info += ESP.getCoreVersion().c_str();
+  device_info += "|Boot: ";
+  device_info += to_string(ESP.getBootVersion());
+  device_info += "|Mode: " + to_string(ESP.getBootMode());
+  device_info += "|CPU: " + to_string(ESP.getCpuFreqMHz());
+  device_info += "|Flash: 0x" + format_hex(ESP.getFlashChipId());
+  device_info += "|Reset: ";
+  device_info += ESP.getResetReason().c_str();
+  device_info += "|";
+  device_info += ESP.getResetInfo().c_str();
 #endif
+
+#ifdef USE_TEXT_SENSOR
+  if (this->device_info_ != nullptr) {
+    if (device_info.length() > 255)
+      device_info.resize(255);
+    this->device_info_->publish_state(device_info);
+  }
+#endif  // USE_TEXT_SENSOR
 }
+
 void DebugComponent::loop() {
-#ifdef USE_ARDUINO
-  uint32_t new_free_heap = ESP.getFreeHeap();  // NOLINT(readability-static-accessed-through-instance)
-#elif defined(USE_ESP_IDF)
-  uint32_t new_free_heap = heap_caps_get_free_size(MALLOC_CAP_INTERNAL);
-#endif
+  // log when free heap space has halved
+  uint32_t new_free_heap = get_free_heap();
   if (new_free_heap < this->free_heap_ / 2) {
     this->free_heap_ = new_free_heap;
     ESP_LOGD(TAG, "Free Heap Size: %u bytes", this->free_heap_);
     this->status_momentary_warning("heap", 1000);
   }
+
+#ifdef USE_SENSOR
+  // calculate loop time - from last call to this one
+  if (this->loop_time_sensor_ != nullptr) {
+    uint32_t now = millis();
+    uint32_t loop_time = now - this->last_loop_timetag_;
+    this->max_loop_time_ = std::max(this->max_loop_time_, loop_time);
+    this->last_loop_timetag_ = now;
+  }
+#endif  // USE_SENSOR
 }
+
+void DebugComponent::update() {
+#ifdef USE_SENSOR
+  if (this->free_sensor_ != nullptr) {
+    this->free_sensor_->publish_state(get_free_heap());
+  }
+
+  if (this->block_sensor_ != nullptr) {
+#if defined(USE_ESP8266)
+    // NOLINTNEXTLINE(readability-static-accessed-through-instance)
+    this->block_sensor_->publish_state(ESP.getMaxFreeBlockSize());
+#elif defined(USE_ESP32)
+    this->block_sensor_->publish_state(heap_caps_get_largest_free_block(MALLOC_CAP_INTERNAL));
+#endif
+  }
+
+#if defined(USE_ESP8266) && USE_ARDUINO_VERSION_CODE >= VERSION_CODE(2, 5, 2)
+  if (this->fragmentation_sensor_ != nullptr) {
+    // NOLINTNEXTLINE(readability-static-accessed-through-instance)
+    this->fragmentation_sensor_->publish_state(ESP.getHeapFragmentation());
+  }
+#endif
+
+  if (this->loop_time_sensor_ != nullptr) {
+    this->loop_time_sensor_->publish_state(this->max_loop_time_);
+    this->max_loop_time_ = 0;
+  }
+#endif  // USE_SENSOR
+}
+
 float DebugComponent::get_setup_priority() const { return setup_priority::LATE; }
 
 }  // namespace debug
