@@ -3,11 +3,14 @@ import esphome.config_validation as cv
 from esphome import pins
 from esphome.const import (
     CONF_ID,
+    CONF_INPUT,
     CONF_NUMBER,
     CONF_MODE,
     CONF_INVERTED,
     CONF_INTERRUPT,
     CONF_OPEN_DRAIN_INTERRUPT,
+    CONF_OUTPUT,
+    CONF_PULLUP,
 )
 from esphome.core import coroutine
 
@@ -16,7 +19,6 @@ CODEOWNERS = ["@jesserockz"]
 mcp23xxx_base_ns = cg.esphome_ns.namespace("mcp23xxx_base")
 MCP23XXXBase = mcp23xxx_base_ns.class_("MCP23XXXBase", cg.Component)
 MCP23XXXGPIOPin = mcp23xxx_base_ns.class_("MCP23XXXGPIOPin", cg.GPIOPin)
-MCP23XXXGPIOMode = mcp23xxx_base_ns.enum("MCP23XXXGPIOMode")
 MCP23XXXInterruptMode = mcp23xxx_base_ns.enum("MCP23XXXInterruptMode")
 
 MCP23XXX_INTERRUPT_MODES = {
@@ -26,12 +28,6 @@ MCP23XXX_INTERRUPT_MODES = {
     "FALLING": MCP23XXXInterruptMode.MCP23XXX_FALLING,
 }
 
-MCP23XXX_GPIO_MODES = {
-    "INPUT": MCP23XXXGPIOMode.MCP23XXX_INPUT,
-    "INPUT_PULLUP": MCP23XXXGPIOMode.MCP23XXX_INPUT_PULLUP,
-    "OUTPUT": MCP23XXXGPIOMode.MCP23XXX_OUTPUT,
-}
-
 MCP23XXX_CONFIG_SCHEMA = cv.Schema(
     {
         cv.Optional(CONF_OPEN_DRAIN_INTERRUPT, default=False): cv.boolean,
@@ -47,26 +43,29 @@ async def register_mcp23xxx(config):
     return var
 
 
+def validate_mode(value):
+    if not (value[CONF_INPUT] or value[CONF_OUTPUT]):
+        raise cv.Invalid("Mode must be either input or output")
+    if value[CONF_INPUT] and value[CONF_OUTPUT]:
+        raise cv.Invalid("Mode must be either input or output")
+    if value[CONF_PULLUP] and not value[CONF_INPUT]:
+        raise cv.Invalid("Pullup only available with input")
+    return value
+
+
 CONF_MCP23XXX = "mcp23xxx"
-MCP23XXX_OUTPUT_PIN_SCHEMA = cv.Schema(
+MCP23XXX_PIN_SCHEMA = cv.All(
     {
+        cv.GenerateID(): cv.declare_id(MCP23XXXGPIOPin),
         cv.Required(CONF_MCP23XXX): cv.use_id(MCP23XXXBase),
-        cv.Required(CONF_NUMBER): cv.int_,
-        cv.Optional(CONF_MODE, default="OUTPUT"): cv.enum(
-            MCP23XXX_GPIO_MODES, upper=True
-        ),
-        cv.Optional(CONF_INVERTED, default=False): cv.boolean,
-        cv.Optional(CONF_INTERRUPT, default="NO_INTERRUPT"): cv.enum(
-            MCP23XXX_INTERRUPT_MODES, upper=True
-        ),
-    }
-)
-MCP23XXX_INPUT_PIN_SCHEMA = cv.Schema(
-    {
-        cv.Required(CONF_MCP23XXX): cv.use_id(MCP23XXXBase),
-        cv.Required(CONF_NUMBER): cv.int_,
-        cv.Optional(CONF_MODE, default="INPUT"): cv.enum(
-            MCP23XXX_GPIO_MODES, upper=True
+        cv.Required(CONF_NUMBER): cv.int_range(min=0, max=15),
+        cv.Optional(CONF_MODE, default={}): cv.All(
+            {
+                cv.Optional(CONF_INPUT, default=False): cv.boolean,
+                cv.Optional(CONF_PULLUP, default=False): cv.boolean,
+                cv.Optional(CONF_OUTPUT, default=False): cv.boolean,
+            },
+            validate_mode,
         ),
         cv.Optional(CONF_INVERTED, default=False): cv.boolean,
         cv.Optional(CONF_INTERRUPT, default="NO_INTERRUPT"): cv.enum(
@@ -76,43 +75,16 @@ MCP23XXX_INPUT_PIN_SCHEMA = cv.Schema(
 )
 
 
-@pins.PIN_SCHEMA_REGISTRY.register(
-    CONF_MCP23XXX, (MCP23XXX_OUTPUT_PIN_SCHEMA, MCP23XXX_INPUT_PIN_SCHEMA)
-)
+@pins.PIN_SCHEMA_REGISTRY.register(CONF_MCP23XXX, MCP23XXX_PIN_SCHEMA)
 async def mcp23xxx_pin_to_code(config):
+    var = cg.new_Pvariable(config[CONF_ID])
     parent = await cg.get_variable(config[CONF_MCP23XXX])
-    return MCP23XXXGPIOPin.new(
-        parent,
-        config[CONF_NUMBER],
-        config[CONF_MODE],
-        config[CONF_INVERTED],
-        config[CONF_INTERRUPT],
-    )
 
+    cg.add(var.set_parent(parent))
 
-# BEGIN Removed pin schemas below to show error in configuration
-# TODO remove in 1.19.0
-
-for id in ["mcp23008", "mcp23s08", "mcp23017", "mcp23s17"]:
-    PIN_SCHEMA = cv.Schema(
-        {
-            cv.Required(id): cv.invalid(
-                f"'{id}:' has been removed from the pin schema in 1.17.0, please use 'mcp23xxx:'"
-            ),
-            cv.Required(CONF_NUMBER): cv.int_,
-            cv.Optional(CONF_MODE, default="INPUT"): cv.enum(
-                MCP23XXX_GPIO_MODES, upper=True
-            ),
-            cv.Optional(CONF_INVERTED, default=False): cv.boolean,
-            cv.Optional(CONF_INTERRUPT, default="NO_INTERRUPT"): cv.enum(
-                MCP23XXX_INTERRUPT_MODES, upper=True
-            ),
-        }
-    )
-
-    @pins.PIN_SCHEMA_REGISTRY.register(id, (PIN_SCHEMA, PIN_SCHEMA))
-    def pin_to_code(config):
-        pass
-
-
-# END Removed pin schemas
+    num = config[CONF_NUMBER]
+    cg.add(var.set_pin(num))
+    cg.add(var.set_inverted(config[CONF_INVERTED]))
+    cg.add(var.set_flags(pins.gpio_flags_expr(config[CONF_MODE])))
+    cg.add(var.set_interrupt_mode(config[CONF_INTERRUPT]))
+    return var
