@@ -4,7 +4,7 @@
 namespace esphome {
 namespace mitsubishi {
 
-static const char *TAG = "mitsubishi.climate";
+static const char *const TAG = "mitsubishi.climate";
 
 const uint32_t MITSUBISHI_OFF = 0x00;
 
@@ -42,8 +42,8 @@ void MitsubishiClimate::transmit_state() {
       break;
   }
 
-  remote_state[7] =
-      (uint8_t) roundf(clamp(this->target_temperature, MITSUBISHI_TEMP_MIN, MITSUBISHI_TEMP_MAX) - MITSUBISHI_TEMP_MIN);
+  remote_state[7] = (uint8_t) roundf(clamp<float>(this->target_temperature, MITSUBISHI_TEMP_MIN, MITSUBISHI_TEMP_MAX) -
+                                     MITSUBISHI_TEMP_MIN);
 
   ESP_LOGV(TAG, "Sending Mitsubishi target temp: %.1f state: %02X mode: %02X temp: %02X", this->target_temperature,
            remote_state[5], remote_state[6], remote_state[7]);
@@ -54,7 +54,7 @@ void MitsubishiClimate::transmit_state() {
   }
 
   auto transmit = this->transmitter_->transmit();
-  auto data = transmit.get_data();
+  auto *data = transmit.get_data();
 
   data->set_carrier_frequency(38000);
   // repeat twice
@@ -63,12 +63,13 @@ void MitsubishiClimate::transmit_state() {
     data->mark(MITSUBISHI_HEADER_MARK);
     data->space(MITSUBISHI_HEADER_SPACE);
     // Data
-    for (uint8_t i : remote_state)
+    for (uint8_t i : remote_state) {
       for (uint8_t j = 0; j < 8; j++) {
         data->mark(MITSUBISHI_BIT_MARK);
         bool bit = i & (1 << j);
         data->space(bit ? MITSUBISHI_ONE_SPACE : MITSUBISHI_ZERO_SPACE);
       }
+    }
     // Footer
     if (r == 0) {
       data->mark(MITSUBISHI_BIT_MARK);
