@@ -18,8 +18,8 @@ void ThermostatClimate::setup() {
   // add a callback so that whenever the sensor state changes we can take action
   this->sensor_->add_on_state_callback([this](float state) {
     this->current_temperature = state;
-    // required action may have changed, recompute, refresh
-    this->switch_to_action_(this->compute_action_());
+    // required action may have changed, recompute, refresh, we'll publish_state() later
+    this->switch_to_action_(this->compute_action_(), false);
     this->switch_to_supplemental_action_(this->compute_supplemental_action_());
     // current temperature and possibly action changed, so publish the new state
     this->publish_state();
@@ -32,10 +32,10 @@ void ThermostatClimate::setup() {
   } else {
     // restore from defaults, change_away handles temps for us
     this->mode = this->default_mode_;
-    this->change_away_(false);
+    this->change_preset_(climate::CLIMATE_PRESET_HOME);
   }
-  // refresh the climate action based on the restored settings
-  this->switch_to_action_(this->compute_action_());
+  // refresh the climate action based on the restored settings, we'll publish_state() later
+  this->switch_to_action_(this->compute_action_(), false);
   this->switch_to_supplemental_action_(this->compute_supplemental_action_());
   this->setup_complete_ = true;
   this->publish_state();
@@ -47,11 +47,11 @@ float ThermostatClimate::heat_deadband() { return this->heating_deadband_; }
 float ThermostatClimate::heat_overrun() { return this->heating_overrun_; }
 
 void ThermostatClimate::refresh() {
-  this->switch_to_mode_(this->mode);
-  this->switch_to_action_(this->compute_action_());
+  this->switch_to_mode_(this->mode, false);
+  this->switch_to_action_(this->compute_action_(), false);
   this->switch_to_supplemental_action_(this->compute_supplemental_action_());
-  this->switch_to_fan_mode_(this->fan_mode.value());
-  this->switch_to_swing_mode_(this->swing_mode);
+  this->switch_to_fan_mode_(this->fan_mode.value(), false);
+  this->switch_to_swing_mode_(this->swing_mode, false);
   this->check_temperature_change_trigger_();
   this->publish_state();
 }
@@ -88,17 +88,17 @@ climate::ClimateFanMode ThermostatClimate::locked_fan_mode() { return this->prev
 
 bool ThermostatClimate::hysteresis_valid() {
   if ((this->supports_cool_ || (this->supports_fan_only_ && this->supports_fan_only_cooling_)) &&
-      (isnan(this->cooling_deadband_) || isnan(this->cooling_overrun_)))
+      (std::isnan(this->cooling_deadband_) || std::isnan(this->cooling_overrun_)))
     return false;
 
-  if (this->supports_heat_ && (isnan(this->heating_deadband_) || isnan(this->heating_overrun_)))
+  if (this->supports_heat_ && (std::isnan(this->heating_deadband_) || std::isnan(this->heating_overrun_)))
     return false;
 
   return true;
 }
 
 void ThermostatClimate::validate_target_temperature() {
-  if (isnan(this->target_temperature)) {
+  if (std::isnan(this->target_temperature)) {
     this->target_temperature =
         ((this->get_traits().get_visual_max_temperature() - this->get_traits().get_visual_min_temperature()) / 2) +
         this->get_traits().get_visual_min_temperature();
@@ -121,7 +121,7 @@ void ThermostatClimate::validate_target_temperatures() {
 }
 
 void ThermostatClimate::validate_target_temperature_low() {
-  if (isnan(this->target_temperature_low)) {
+  if (std::isnan(this->target_temperature_low)) {
     this->target_temperature_low = this->get_traits().get_visual_min_temperature();
   } else {
     // target_temperature_low must not be lower than the visual minimum
@@ -129,9 +129,10 @@ void ThermostatClimate::validate_target_temperature_low() {
       this->target_temperature_low = this->get_traits().get_visual_min_temperature();
     // target_temperature_low must not be greater than the visual maximum minus set_point_minimum_differential_
     if (this->target_temperature_low >
-        this->get_traits().get_visual_max_temperature() - this->set_point_minimum_differential_)
+        this->get_traits().get_visual_max_temperature() - this->set_point_minimum_differential_) {
       this->target_temperature_low =
           this->get_traits().get_visual_max_temperature() - this->set_point_minimum_differential_;
+    }
     // if target_temperature_low is set greater than target_temperature_high, move up target_temperature_high
     if (this->target_temperature_low > this->target_temperature_high - this->set_point_minimum_differential_)
       this->target_temperature_high = this->target_temperature_low + this->set_point_minimum_differential_;
@@ -139,7 +140,7 @@ void ThermostatClimate::validate_target_temperature_low() {
 }
 
 void ThermostatClimate::validate_target_temperature_high() {
-  if (isnan(this->target_temperature_high)) {
+  if (std::isnan(this->target_temperature_high)) {
     this->target_temperature_high = this->get_traits().get_visual_max_temperature();
   } else {
     // target_temperature_high must not be lower than the visual maximum
@@ -147,9 +148,10 @@ void ThermostatClimate::validate_target_temperature_high() {
       this->target_temperature_high = this->get_traits().get_visual_max_temperature();
     // target_temperature_high must not be lower than the visual minimum plus set_point_minimum_differential_
     if (this->target_temperature_high <
-        this->get_traits().get_visual_min_temperature() + this->set_point_minimum_differential_)
+        this->get_traits().get_visual_min_temperature() + this->set_point_minimum_differential_) {
       this->target_temperature_high =
           this->get_traits().get_visual_min_temperature() + this->set_point_minimum_differential_;
+    }
     // if target_temperature_high is set less than target_temperature_low, move down target_temperature_low
     if (this->target_temperature_high < this->target_temperature_low + this->set_point_minimum_differential_)
       this->target_temperature_low = this->target_temperature_high - this->set_point_minimum_differential_;
@@ -160,11 +162,20 @@ void ThermostatClimate::control(const climate::ClimateCall &call) {
   if (call.get_preset().has_value()) {
     // setup_complete_ blocks modifying/resetting the temps immediately after boot
     if (this->setup_complete_) {
-      this->change_away_(*call.get_preset() == climate::CLIMATE_PRESET_AWAY);
+      this->change_preset_(*call.get_preset());
     } else {
       this->preset = *call.get_preset();
     }
   }
+  if (call.get_custom_preset().has_value()) {
+    // setup_complete_ blocks modifying/resetting the temps immediately after boot
+    if (this->setup_complete_) {
+      this->change_custom_preset_(*call.get_custom_preset());
+    } else {
+      this->custom_preset = *call.get_custom_preset();
+    }
+  }
+
   if (call.get_mode().has_value())
     this->mode = *call.get_mode();
   if (call.get_fan_mode().has_value())
@@ -234,8 +245,12 @@ climate::ClimateTraits ThermostatClimate::traits() {
   if (supports_swing_mode_vertical_)
     traits.add_supported_swing_mode(climate::CLIMATE_SWING_VERTICAL);
 
-  if (supports_away_)
-    traits.set_supported_presets({climate::CLIMATE_PRESET_HOME, climate::CLIMATE_PRESET_AWAY});
+  for (auto &it : this->preset_config_) {
+    traits.add_supported_preset(it.first);
+  }
+  for (auto &it : this->custom_preset_config_) {
+    traits.add_supported_custom_preset(it.first);
+  }
 
   traits.set_supports_two_point_target_temperature(this->supports_two_points_);
   traits.set_supports_action(true);
@@ -245,7 +260,7 @@ climate::ClimateTraits ThermostatClimate::traits() {
 climate::ClimateAction ThermostatClimate::compute_action_(const bool ignore_timers) {
   auto target_action = climate::CLIMATE_ACTION_IDLE;
   // if any hysteresis values or current_temperature is not valid, we go to OFF;
-  if (isnan(this->current_temperature) || !this->hysteresis_valid()) {
+  if (std::isnan(this->current_temperature) || !this->hysteresis_valid()) {
     return climate::CLIMATE_ACTION_OFF;
   }
   // do not change the action if an "ON" timer is running
@@ -307,7 +322,7 @@ climate::ClimateAction ThermostatClimate::compute_action_(const bool ignore_time
 climate::ClimateAction ThermostatClimate::compute_supplemental_action_() {
   auto target_action = climate::CLIMATE_ACTION_IDLE;
   // if any hysteresis values or current_temperature is not valid, we go to OFF;
-  if (isnan(this->current_temperature) || !this->hysteresis_valid()) {
+  if (std::isnan(this->current_temperature) || !this->hysteresis_valid()) {
     return climate::CLIMATE_ACTION_OFF;
   }
 
@@ -346,11 +361,12 @@ climate::ClimateAction ThermostatClimate::compute_supplemental_action_() {
   return target_action;
 }
 
-void ThermostatClimate::switch_to_action_(climate::ClimateAction action) {
+void ThermostatClimate::switch_to_action_(climate::ClimateAction action, bool publish_state) {
   // setup_complete_ helps us ensure an action is called immediately after boot
-  if ((action == this->action) && this->setup_complete_)
+  if ((action == this->action) && this->setup_complete_) {
     // already in target mode
     return;
+  }
 
   if (((action == climate::CLIMATE_ACTION_OFF && this->action == climate::CLIMATE_ACTION_IDLE) ||
        (action == climate::CLIMATE_ACTION_IDLE && this->action == climate::CLIMATE_ACTION_OFF)) &&
@@ -358,6 +374,8 @@ void ThermostatClimate::switch_to_action_(climate::ClimateAction action) {
     // switching from OFF to IDLE or vice-versa -- this is only a visual difference.
     // OFF means user manually disabled, IDLE means the temperature is in target range.
     this->action = action;
+    if (publish_state)
+      this->publish_state();
     return;
   }
 
@@ -371,10 +389,11 @@ void ThermostatClimate::switch_to_action_(climate::ClimateAction action) {
         if (this->action == climate::CLIMATE_ACTION_COOLING)
           this->start_timer_(thermostat::TIMER_COOLING_OFF);
         if (this->action == climate::CLIMATE_ACTION_FAN) {
-          if (this->supports_fan_only_action_uses_fan_mode_timer_)
+          if (this->supports_fan_only_action_uses_fan_mode_timer_) {
             this->start_timer_(thermostat::TIMER_FAN_MODE);
-          else
+          } else {
             this->start_timer_(thermostat::TIMER_FANNING_OFF);
+          }
         }
         if (this->action == climate::CLIMATE_ACTION_HEATING)
           this->start_timer_(thermostat::TIMER_HEATING_OFF);
@@ -413,10 +432,11 @@ void ThermostatClimate::switch_to_action_(climate::ClimateAction action) {
       break;
     case climate::CLIMATE_ACTION_FAN:
       if (this->fanning_action_ready_()) {
-        if (this->supports_fan_only_action_uses_fan_mode_timer_)
+        if (this->supports_fan_only_action_uses_fan_mode_timer_) {
           this->start_timer_(thermostat::TIMER_FAN_MODE);
-        else
+        } else {
           this->start_timer_(thermostat::TIMER_FANNING_ON);
+        }
         trig = this->fan_only_action_trigger_;
         ESP_LOGVV(TAG, "Switching to FAN_ONLY action");
         action_ready = true;
@@ -452,14 +472,17 @@ void ThermostatClimate::switch_to_action_(climate::ClimateAction action) {
       ESP_LOGVV(TAG, "Calling FAN_ONLY action with HEATING/COOLING action");
       trig_fan->trigger();
     }
+    if (publish_state)
+      this->publish_state();
   }
 }
 
 void ThermostatClimate::switch_to_supplemental_action_(climate::ClimateAction action) {
   // setup_complete_ helps us ensure an action is called immediately after boot
-  if ((action == this->supplemental_action_) && this->setup_complete_)
+  if ((action == this->supplemental_action_) && this->setup_complete_) {
     // already in target mode
     return;
+  }
 
   switch (action) {
     case climate::CLIMATE_ACTION_OFF:
@@ -509,13 +532,16 @@ void ThermostatClimate::trigger_supplemental_action_() {
   }
 }
 
-void ThermostatClimate::switch_to_fan_mode_(climate::ClimateFanMode fan_mode) {
+void ThermostatClimate::switch_to_fan_mode_(climate::ClimateFanMode fan_mode, bool publish_state) {
   // setup_complete_ helps us ensure an action is called immediately after boot
-  if ((fan_mode == this->prev_fan_mode_) && this->setup_complete_)
+  if ((fan_mode == this->prev_fan_mode_) && this->setup_complete_) {
     // already in target mode
     return;
+  }
 
   this->fan_mode = fan_mode;
+  if (publish_state)
+    this->publish_state();
 
   if (this->fan_mode_ready_()) {
     Trigger<> *trig = this->fan_mode_auto_trigger_;
@@ -574,11 +600,12 @@ void ThermostatClimate::switch_to_fan_mode_(climate::ClimateFanMode fan_mode) {
   }
 }
 
-void ThermostatClimate::switch_to_mode_(climate::ClimateMode mode) {
+void ThermostatClimate::switch_to_mode_(climate::ClimateMode mode, bool publish_state) {
   // setup_complete_ helps us ensure an action is called immediately after boot
-  if ((mode == this->prev_mode_) && this->setup_complete_)
+  if ((mode == this->prev_mode_) && this->setup_complete_) {
     // already in target mode
     return;
+  }
 
   if (this->prev_mode_trigger_ != nullptr) {
     this->prev_mode_trigger_->stop_action();
@@ -615,13 +642,16 @@ void ThermostatClimate::switch_to_mode_(climate::ClimateMode mode) {
   this->mode = mode;
   this->prev_mode_ = mode;
   this->prev_mode_trigger_ = trig;
+  if (publish_state)
+    this->publish_state();
 }
 
-void ThermostatClimate::switch_to_swing_mode_(climate::ClimateSwingMode swing_mode) {
+void ThermostatClimate::switch_to_swing_mode_(climate::ClimateSwingMode swing_mode, bool publish_state) {
   // setup_complete_ helps us ensure an action is called immediately after boot
-  if ((swing_mode == this->prev_swing_mode_) && this->setup_complete_)
+  if ((swing_mode == this->prev_swing_mode_) && this->setup_complete_) {
     // already in target mode
     return;
+  }
 
   if (this->prev_swing_mode_trigger_ != nullptr) {
     this->prev_swing_mode_trigger_->stop_action();
@@ -652,6 +682,8 @@ void ThermostatClimate::switch_to_swing_mode_(climate::ClimateSwingMode swing_mo
   this->swing_mode = swing_mode;
   this->prev_swing_mode_ = swing_mode;
   this->prev_swing_mode_trigger_ = trig;
+  if (publish_state)
+    this->publish_state();
 }
 
 bool ThermostatClimate::idle_action_ready_() {
@@ -891,30 +923,112 @@ bool ThermostatClimate::supplemental_heating_required_() {
           (this->supplemental_action_ == climate::CLIMATE_ACTION_HEATING));
 }
 
-void ThermostatClimate::change_away_(bool away) {
-  if (!away) {
+void ThermostatClimate::dump_preset_config_(const std::string &preset,
+                                            const ThermostatClimateTargetTempConfig &config) {
+  const auto *preset_name = preset.c_str();
+
+  if (this->supports_heat_) {
     if (this->supports_two_points_) {
-      this->target_temperature_low = this->normal_config_.default_temperature_low;
-      this->target_temperature_high = this->normal_config_.default_temperature_high;
-    } else
-      this->target_temperature = this->normal_config_.default_temperature;
-  } else {
+      ESP_LOGCONFIG(TAG, "      %s Default Target Temperature Low: %.1f°C", preset_name,
+                    config.default_temperature_low);
+    } else {
+      ESP_LOGCONFIG(TAG, "      %s Default Target Temperature Low: %.1f°C", preset_name, config.default_temperature);
+    }
+  }
+  if ((this->supports_cool_) || (this->supports_fan_only_)) {
     if (this->supports_two_points_) {
-      this->target_temperature_low = this->away_config_.default_temperature_low;
-      this->target_temperature_high = this->away_config_.default_temperature_high;
-    } else
-      this->target_temperature = this->away_config_.default_temperature;
+      ESP_LOGCONFIG(TAG, "      %s Default Target Temperature High: %.1f°C", preset_name,
+                    config.default_temperature_high);
+    } else {
+      ESP_LOGCONFIG(TAG, "      %s Default Target Temperature High: %.1f°C", preset_name, config.default_temperature);
+    }
+  }
+
+  if (config.mode_.has_value()) {
+    ESP_LOGCONFIG(TAG, "      %s Default Mode: %s", preset_name,
+                  LOG_STR_ARG(climate::climate_mode_to_string(*config.mode_)));
+  }
+  if (config.fan_mode_.has_value()) {
+    ESP_LOGCONFIG(TAG, "      %s Default Fan Mode: %s", preset_name,
+                  LOG_STR_ARG(climate::climate_fan_mode_to_string(*config.fan_mode_)));
+  }
+  if (config.swing_mode_.has_value()) {
+    ESP_LOGCONFIG(TAG, "      %s Default Swing Mode: %s", preset_name,
+                  LOG_STR_ARG(climate::climate_swing_mode_to_string(*config.swing_mode_)));
   }
-  this->preset = away ? climate::CLIMATE_PRESET_AWAY : climate::CLIMATE_PRESET_HOME;
 }
 
-void ThermostatClimate::set_normal_config(const ThermostatClimateTargetTempConfig &normal_config) {
-  this->normal_config_ = normal_config;
+void ThermostatClimate::change_preset_(climate::ClimatePreset preset) {
+  auto config = this->preset_config_.find(preset);
+
+  if (config != this->preset_config_.end()) {
+    ESP_LOGI(TAG, "Switching to preset  %s", LOG_STR_ARG(climate::climate_preset_to_string(preset)));
+    this->change_preset_internal_(config->second);
+
+    this->custom_preset.reset();
+    this->preset = preset;
+  } else {
+    ESP_LOGE(TAG, "Preset %s is not configured, ignoring.", LOG_STR_ARG(climate::climate_preset_to_string(preset)));
+  }
 }
 
-void ThermostatClimate::set_away_config(const ThermostatClimateTargetTempConfig &away_config) {
-  this->supports_away_ = true;
-  this->away_config_ = away_config;
+void ThermostatClimate::change_custom_preset_(const std::string &custom_preset) {
+  auto config = this->custom_preset_config_.find(custom_preset);
+
+  if (config != this->custom_preset_config_.end()) {
+    ESP_LOGI(TAG, "Switching to custom preset  %s", custom_preset.c_str());
+    this->change_preset_internal_(config->second);
+
+    this->preset.reset();
+    this->custom_preset = custom_preset;
+  } else {
+    ESP_LOGE(TAG, "Custom Preset %s is not configured, ignoring.", custom_preset.c_str());
+  }
+}
+
+void ThermostatClimate::change_preset_internal_(const ThermostatClimateTargetTempConfig &config) {
+  if (this->supports_two_points_) {
+    this->target_temperature_low = config.default_temperature_low;
+    this->target_temperature_high = config.default_temperature_high;
+  } else {
+    this->target_temperature = config.default_temperature;
+  }
+
+  // Note: The mode, fan_mode, and swing_mode can all be defined on the preset but if the climate.control call
+  // also specifies them then the control's version will override these for that call
+  if (config.mode_.has_value()) {
+    this->mode = *config.mode_;
+    ESP_LOGV(TAG, "Setting mode to %s", LOG_STR_ARG(climate::climate_mode_to_string(*config.mode_)));
+  }
+
+  if (config.fan_mode_.has_value()) {
+    this->fan_mode = *config.fan_mode_;
+    ESP_LOGV(TAG, "Setting fan mode to %s", LOG_STR_ARG(climate::climate_fan_mode_to_string(*config.fan_mode_)));
+  }
+
+  if (config.swing_mode_.has_value()) {
+    ESP_LOGV(TAG, "Setting swing mode to %s", LOG_STR_ARG(climate::climate_swing_mode_to_string(*config.swing_mode_)));
+    this->swing_mode = *config.swing_mode_;
+  }
+
+  // Fire any preset changed trigger if defined
+  if (this->preset != preset) {
+    Trigger<> *trig = this->preset_change_trigger_;
+    assert(trig != nullptr);
+    trig->trigger();
+  }
+
+  this->refresh();
+}
+
+void ThermostatClimate::set_preset_config(climate::ClimatePreset preset,
+                                          const ThermostatClimateTargetTempConfig &config) {
+  this->preset_config_[preset] = config;
+}
+
+void ThermostatClimate::set_custom_preset_config(const std::string &name,
+                                                 const ThermostatClimateTargetTempConfig &config) {
+  this->custom_preset_config_[name] = config;
 }
 
 ThermostatClimate::ThermostatClimate()
@@ -944,7 +1058,8 @@ ThermostatClimate::ThermostatClimate()
       swing_mode_off_trigger_(new Trigger<>()),
       swing_mode_horizontal_trigger_(new Trigger<>()),
       swing_mode_vertical_trigger_(new Trigger<>()),
-      temperature_change_trigger_(new Trigger<>()) {}
+      temperature_change_trigger_(new Trigger<>()),
+      preset_change_trigger_(new Trigger<>()) {}
 
 void ThermostatClimate::set_default_mode(climate::ClimateMode default_mode) { this->default_mode_ = default_mode; }
 void ThermostatClimate::set_set_point_minimum_differential(float differential) {
@@ -1093,21 +1208,11 @@ Trigger<> *ThermostatClimate::get_swing_mode_off_trigger() const { return this->
 Trigger<> *ThermostatClimate::get_swing_mode_horizontal_trigger() const { return this->swing_mode_horizontal_trigger_; }
 Trigger<> *ThermostatClimate::get_swing_mode_vertical_trigger() const { return this->swing_mode_vertical_trigger_; }
 Trigger<> *ThermostatClimate::get_temperature_change_trigger() const { return this->temperature_change_trigger_; }
+Trigger<> *ThermostatClimate::get_preset_change_trigger() const { return this->preset_change_trigger_; }
 
 void ThermostatClimate::dump_config() {
   LOG_CLIMATE("", "Thermostat", this);
-  if (this->supports_heat_) {
-    if (this->supports_two_points_)
-      ESP_LOGCONFIG(TAG, "  Default Target Temperature Low: %.1f°C", this->normal_config_.default_temperature_low);
-    else
-      ESP_LOGCONFIG(TAG, "  Default Target Temperature Low: %.1f°C", this->normal_config_.default_temperature);
-  }
-  if ((this->supports_cool_) || (this->supports_fan_only_ && this->supports_fan_only_cooling_)) {
-    if (this->supports_two_points_)
-      ESP_LOGCONFIG(TAG, "  Default Target Temperature High: %.1f°C", this->normal_config_.default_temperature_high);
-    else
-      ESP_LOGCONFIG(TAG, "  Default Target Temperature High: %.1f°C", this->normal_config_.default_temperature);
-  }
+
   if (this->supports_two_points_)
     ESP_LOGCONFIG(TAG, "  Minimum Set Point Differential: %.1f°C", this->set_point_minimum_differential_);
   ESP_LOGCONFIG(TAG, "  Start-up Delay Enabled: %s", YESNO(this->use_startup_delay_));
@@ -1173,22 +1278,21 @@ void ThermostatClimate::dump_config() {
   ESP_LOGCONFIG(TAG, "  Supports SWING MODE HORIZONTAL: %s", YESNO(this->supports_swing_mode_horizontal_));
   ESP_LOGCONFIG(TAG, "  Supports SWING MODE VERTICAL: %s", YESNO(this->supports_swing_mode_vertical_));
   ESP_LOGCONFIG(TAG, "  Supports TWO SET POINTS: %s", YESNO(this->supports_two_points_));
-  ESP_LOGCONFIG(TAG, "  Supports AWAY mode: %s", YESNO(this->supports_away_));
-  if (this->supports_away_) {
-    if (this->supports_heat_) {
-      if (this->supports_two_points_)
-        ESP_LOGCONFIG(TAG, "    Away Default Target Temperature Low: %.1f°C",
-                      this->away_config_.default_temperature_low);
-      else
-        ESP_LOGCONFIG(TAG, "    Away Default Target Temperature Low: %.1f°C", this->away_config_.default_temperature);
-    }
-    if ((this->supports_cool_) || (this->supports_fan_only_)) {
-      if (this->supports_two_points_)
-        ESP_LOGCONFIG(TAG, "    Away Default Target Temperature High: %.1f°C",
-                      this->away_config_.default_temperature_high);
-      else
-        ESP_LOGCONFIG(TAG, "    Away Default Target Temperature High: %.1f°C", this->away_config_.default_temperature);
-    }
+
+  ESP_LOGCONFIG(TAG, "  Supported PRESETS: ");
+  for (auto &it : this->preset_config_) {
+    const auto *preset_name = LOG_STR_ARG(climate::climate_preset_to_string(it.first));
+
+    ESP_LOGCONFIG(TAG, "    Supports %s: %s", preset_name, YESNO(true));
+    this->dump_preset_config_(preset_name, it.second);
+  }
+
+  ESP_LOGCONFIG(TAG, "  Supported CUSTOM PRESETS: ");
+  for (auto &it : this->custom_preset_config_) {
+    const auto *preset_name = it.first.c_str();
+
+    ESP_LOGCONFIG(TAG, "    Supports %s: %s", preset_name, YESNO(true));
+    this->dump_preset_config_(preset_name, it.second);
   }
 }
 
