@@ -1,12 +1,13 @@
 #include "tof10120_sensor.h"
 #include "esphome/core/log.h"
+#include "esphome/core/hal.h"
 
 // Very basic support for TOF10120 distance sensor
 
 namespace esphome {
 namespace tof10120 {
 
-static const char *TAG = "tof10120";
+static const char *const TAG = "tof10120";
 static const uint8_t TOF10120_READ_DISTANCE_CMD[] = {0x00};
 static const uint8_t TOF10120_DEFAULT_DELAY = 30;
 
@@ -31,7 +32,12 @@ void TOF10120Sensor::update() {
   }
 
   uint8_t data[2];
-  if (!this->read_bytes(TOF10120_DISTANCE_REGISTER, data, 2, TOF10120_DEFAULT_DELAY)) {
+  if (this->write(&TOF10120_DISTANCE_REGISTER, 1) != i2c::ERROR_OK) {
+    this->status_set_warning();
+    return;
+  }
+  delay(TOF10120_DEFAULT_DELAY);
+  if (this->read(data, 2) != i2c::ERROR_OK) {
     ESP_LOGE(TAG, "Communication with TOF10120 failed on read");
     this->status_set_warning();
     return;
@@ -44,7 +50,7 @@ void TOF10120Sensor::update() {
     ESP_LOGW(TAG, "Distance measurement out of range");
     this->publish_state(NAN);
   } else {
-    this->publish_state(distance_mm / 1000.0);
+    this->publish_state(distance_mm / 1000.0f);
   }
   this->status_clear_warning();
 }
