@@ -1,6 +1,6 @@
 """Constants used by esphome."""
 
-__version__ = "2022.4.0"
+__version__ = "2022.8.0"
 
 ALLOWED_NAME_CHARS = "abcdefghijklmnopqrstuvwxyz0123456789-_"
 
@@ -88,6 +88,7 @@ CONF_CERTIFICATE_AUTHORITY = "certificate_authority"
 CONF_CHANGE_MODE_EVERY = "change_mode_every"
 CONF_CHANNEL = "channel"
 CONF_CHANNELS = "channels"
+CONF_CHARACTERISTIC_UUID = "characteristic_uuid"
 CONF_CHIPSET = "chipset"
 CONF_CLEAR_IMPEDANCE = "clear_impedance"
 CONF_CLIENT_ID = "client_id"
@@ -105,6 +106,7 @@ CONF_COLOR_BRIGHTNESS = "color_brightness"
 CONF_COLOR_CORRECT = "color_correct"
 CONF_COLOR_INTERLOCK = "color_interlock"
 CONF_COLOR_MODE = "color_mode"
+CONF_COLOR_PALETTE = "color_palette"
 CONF_COLOR_TEMPERATURE = "color_temperature"
 CONF_COLORS = "colors"
 CONF_COMMAND = "command"
@@ -125,6 +127,7 @@ CONF_COOL_MODE = "cool_mode"
 CONF_COOL_OVERRUN = "cool_overrun"
 CONF_COUNT = "count"
 CONF_COUNT_MODE = "count_mode"
+CONF_COUNTS = "counts"
 CONF_COURSE = "course"
 CONF_CRON = "cron"
 CONF_CS_PIN = "cs_pin"
@@ -138,6 +141,7 @@ CONF_CUSTOM_FAN_MODE = "custom_fan_mode"
 CONF_CUSTOM_FAN_MODES = "custom_fan_modes"
 CONF_CUSTOM_PRESET = "custom_preset"
 CONF_CUSTOM_PRESETS = "custom_presets"
+CONF_CYCLE = "cycle"
 CONF_DALLAS_ID = "dallas_id"
 CONF_DATA = "data"
 CONF_DATA_PIN = "data_pin"
@@ -162,6 +166,7 @@ CONF_DELTA = "delta"
 CONF_DEVICE = "device"
 CONF_DEVICE_CLASS = "device_class"
 CONF_DEVICE_FACTOR = "device_factor"
+CONF_DIELECTRIC_CONSTANT = "dielectric_constant"
 CONF_DIMENSIONS = "dimensions"
 CONF_DIO_PIN = "dio_pin"
 CONF_DIR_PIN = "dir_pin"
@@ -197,6 +202,7 @@ CONF_ENABLE_TIME = "enable_time"
 CONF_ENERGY = "energy"
 CONF_ENTITY_CATEGORY = "entity_category"
 CONF_ENTITY_ID = "entity_id"
+CONF_ENUM_DATAPOINT = "enum_datapoint"
 CONF_ESP8266_DISABLE_SSL_SUPPORT = "esp8266_disable_ssl_support"
 CONF_ESPHOME = "esphome"
 CONF_ETHERNET = "ethernet"
@@ -458,6 +464,7 @@ CONF_OPEN_DRAIN = "open_drain"
 CONF_OPEN_DRAIN_INTERRUPT = "open_drain_interrupt"
 CONF_OPEN_DURATION = "open_duration"
 CONF_OPEN_ENDSTOP = "open_endstop"
+CONF_OPERATION = "operation"
 CONF_OPTIMISTIC = "optimistic"
 CONF_OPTION = "option"
 CONF_OPTIONS = "options"
@@ -529,6 +536,7 @@ CONF_PRESSURE = "pressure"
 CONF_PRIORITY = "priority"
 CONF_PROJECT = "project"
 CONF_PROTOCOL = "protocol"
+CONF_PUBLISH_INITIAL_STATE = "publish_initial_state"
 CONF_PULL_MODE = "pull_mode"
 CONF_PULLDOWN = "pulldown"
 CONF_PULLUP = "pullup"
@@ -745,6 +753,7 @@ CONF_WAND_ID = "wand_id"
 CONF_WARM_WHITE = "warm_white"
 CONF_WARM_WHITE_COLOR_TEMPERATURE = "warm_white_color_temperature"
 CONF_WATCHDOG_THRESHOLD = "watchdog_threshold"
+CONF_WEB_SERVER = "web_server"
 CONF_WEIGHT = "weight"
 CONF_WHILE = "while"
 CONF_WHITE = "white"
@@ -901,11 +910,15 @@ DEVICE_CLASS_BATTERY = "battery"
 DEVICE_CLASS_GAS = "gas"
 DEVICE_CLASS_POWER = "power"
 # device classes of sensor component
+DEVICE_CLASS_APPARENT_POWER = "apparent_power"
 DEVICE_CLASS_AQI = "aqi"
 DEVICE_CLASS_CARBON_DIOXIDE = "carbon_dioxide"
 DEVICE_CLASS_CARBON_MONOXIDE = "carbon_monoxide"
 DEVICE_CLASS_CURRENT = "current"
+DEVICE_CLASS_DATE = "date"
+DEVICE_CLASS_DURATION = "duration"
 DEVICE_CLASS_ENERGY = "energy"
+DEVICE_CLASS_FREQUENCY = "frequency"
 DEVICE_CLASS_HUMIDITY = "humidity"
 DEVICE_CLASS_ILLUMINANCE = "illuminance"
 DEVICE_CLASS_MONETARY = "monetary"
@@ -918,6 +931,7 @@ DEVICE_CLASS_PM10 = "pm10"
 DEVICE_CLASS_PM25 = "pm25"
 DEVICE_CLASS_POWER_FACTOR = "power_factor"
 DEVICE_CLASS_PRESSURE = "pressure"
+DEVICE_CLASS_REACTIVE_POWER = "reactive_power"
 DEVICE_CLASS_SIGNAL_STRENGTH = "signal_strength"
 DEVICE_CLASS_SULPHUR_DIOXIDE = "sulphur_dioxide"
 DEVICE_CLASS_TEMPERATURE = "temperature"
@@ -942,6 +956,9 @@ STATE_CLASS_MEASUREMENT = "measurement"
 # The state represents a total that only increases, a decrease is considered a reset.
 STATE_CLASS_TOTAL_INCREASING = "total_increasing"
 
+# The state represents a total amount that can both increase and decrease, e.g. a net energy meter.
+STATE_CLASS_TOTAL = "total"
+
 KEY_CORE = "core"
 KEY_TARGET_PLATFORM = "target_platform"
 KEY_TARGET_FRAMEWORK = "target_framework"
